@@ -73,6 +73,9 @@ class Command(BaseCommand):
                 _('Sub Type')),
             ('item', sync.ItemSynchronizer,
                 _('Item')),
+            ('type_subtype_item_association',
+             sync.TypeSubTypeItemAssociationSynchronizer,
+             _('Type Subtype Item Association')),
             ('ticket', sync.ServiceTicketSynchronizer, _('Ticket')),
             ('project_ticket', sync.ProjectTicketSynchronizer,
                 _('Project Ticket')),
